@@ -28,15 +28,15 @@ def copyTemplates(projectname: str, cli: bool):
     PROJECT_PATH.mkdir(exist_ok=True, parents=True)
     (PROJECT_ROOT / 'src' / '__init__.py').touch(exist_ok=True)
     for file in (DIR / 'code').iterdir():
-        if file.stem == '_config':
-            shutil.copytree(file, PROJECT_PATH / file.stem)
         if file.stem == 'scripts':
             shutil.copytree(file, PROJECT_ROOT / file.stem)
         elif file.stem == 'test':
             shutil.copytree(file, PROJECT_ROOT / file.stem)
+        elif file.stem == '_config':
+            shutil.copytree(file, PROJECT_ROOT / 'src' / file.stem)
         elif file.stem == 'main.py':
             data = {'projectname': projectname, 'cli': cli}
-            writeTemplate('main.py', PROJECT_PATH, data=data, templatepath=DIR / 'code')
+            writeTemplate('main.py', PROJECT_ROOT / 'src', data=data, templatepath=DIR / 'code')
         else:
             if not file.is_dir():
                 shutil.copy(file, PROJECT_PATH / file.name)
@@ -72,6 +72,7 @@ def createFiles(projectname: str, cli: bool, python_version: str):
         writeTemplate(tmpl, PROJECT_ROOT, data=data)
 
     writeTemplate('settings.json', PROJECT_ROOT / '.vscode', data=data)
+    writeTemplate('extensions.json', PROJECT_ROOT / '.vscode', data=data)
 
     pkg_tmpl = ['LICENSE', 'setup.cfg', 'pyproject.toml', 'MANIFEST.in']
     for tmpl in pkg_tmpl:
